@@ -134,10 +134,10 @@ bool ProcessesLocal::Private::readProcStatus(const QString &dir, Process *proces
     if(!mFile.open(QIODevice::ReadOnly))
         return false;      /* process has terminated in the meantime */
 
-    process->uid = 0;
-    process->gid = 0;
-    process->tracerpid = -1;
-    process->numThreads = 0;
+    process->setUid(0);
+    process->setGid(0);
+    process->setTracerpid(-1);
+    process->setNumThreads(0);
 
     int size;
     int found = 0; //count how many fields we found
@@ -145,28 +145,41 @@ bool ProcessesLocal::Private::readProcStatus(const QString &dir, Process *proces
         switch( mBuffer[0]) {
 	  case 'N':
 	    if((unsigned int)size > sizeof("Name:") && qstrncmp(mBuffer, "Name:", sizeof("Name:")-1) == 0) {
-	        if(process->command.isEmpty())
+	        if(process->command().isEmpty())
                 process->setName(QString::fromLocal8Bit(mBuffer + sizeof("Name:")-1, size-sizeof("Name:")+1).trimmed());
 	        if(++found == 5) goto finish;
 	    }
 	    break;
 	  case 'U':
 	    if((unsigned int)size > sizeof("Uid:") && qstrncmp(mBuffer, "Uid:", sizeof("Uid:")-1) == 0) {
-            sscanf(mBuffer + sizeof("Uid:") -1, "%Ld %Ld %Ld %Ld", &process->uid, &process->euid, &process->suid, &process->fsuid );
+            qlonglong uid;
+            qlonglong euid;
+            qlonglong suid;
+            qlonglong fsuid;
+            sscanf(mBuffer + sizeof("Uid:") -1, "%Ld %Ld %Ld %Ld", &uid, &euid, &suid, &fsuid);
+            process->setUid(uid);
+            process->setEuid(euid);
+            process->setSuid(suid);
+            process->setFsuid(fsuid);
 	        if(++found == 5) goto finish;
 	    }
 	    break;
 	  case 'G':
 	    if((unsigned int)size > sizeof("Gid:") && qstrncmp(mBuffer, "Gid:", sizeof("Gid:")-1) == 0) {
-            sscanf(mBuffer + sizeof("Gid:")-1, "%Ld %Ld %Ld %Ld", &process->gid, &process->egid, &process->sgid, &process->fsgid );
+            qlonglong gid, egid, sgid, fsgid;
+            sscanf(mBuffer + sizeof("Gid:")-1, "%Ld %Ld %Ld %Ld", &gid, &egid, &sgid, &fsgid);
+            process->setGid(gid);
+            process->setEgid(egid);
+            process->setSgid(sgid);
+            process->setFsgid(fsgid);
 	        if(++found == 5) goto finish;
 	    }
 	    break;
       case 'T':
         if((unsigned int)size > sizeof("TracerPid:") && qstrncmp(mBuffer, "TracerPid:", sizeof("TracerPid:")-1) == 0) {
-            process->tracerpid = atol(mBuffer + sizeof("TracerPid:")-1);
-            if (process->tracerpid == 0)
-                process->tracerpid = -1;
+            process->setTracerpid(atol(mBuffer + sizeof("TracerPid:")-1));
+            if (process->tracerpid() == 0)
+                process->setTracerpid(-1);
             if(++found == 5) goto finish;
         } else if((unsigned int)size > sizeof("Threads:") && qstrncmp(mBuffer, "Threads:", sizeof("Threads:")-1) == 0) {
             process->setNumThreads(atol(mBuffer + sizeof("Threads:")-1));
@@ -286,6 +299,9 @@ bool ProcessesLocal::Private::readProcStat(const QString &dir, Process *ps)
                 case 18: //niceLevel
                     ps->setNiceLevel(atoi(word+1));  /*Or should we use getPriority instead? */
                     break;
+                case 21: // startTime
+                    ps->setStartTime(atoll(word+1));
+                    break;
                 case 22: //vmSize
                     vmSize = atoll(word+1);
                     break;
@@ -365,9 +381,9 @@ bool ProcessesLocal::Private::readProcStatm(const QString &dir, Process *process
     long shared = atol(word+1);
 
     /* we use the rss - shared  to find the amount of memory just this app uses */
-    process->vmURSS = process->vmRSS - (shared * sysconf(_SC_PAGESIZE) / 1024);
+    process->setVmURSS(process->vmRSS() - (shared * sysconf(_SC_PAGESIZE) / 1024));
 #else
-    process->vmURSS = 0;
+    process->setVmURSS(0);
 #endif
     return true;
 }
@@ -375,28 +391,28 @@ bool ProcessesLocal::Private::readProcStatm(const QString &dir, Process *process
 
 bool ProcessesLocal::Private::readProcCmdline(const QString &dir, Process *process)
 {
-    if(!process->command.isNull()) return true; //only parse the cmdline once.  This function takes up 25% of the CPU time :-/
+    if(!process->command().isNull()) return true; //only parse the cmdline once.  This function takes up 25% of the CPU time :-/
     mFile.setFileName(dir + "cmdline");
     if(!mFile.open(QIODevice::ReadOnly))
         return false;      /* process has terminated in the meantime */
 
     QTextStream in(&mFile);
-    process->command = in.readAll();
+    process->setCommand(in.readAll());
 
     //cmdline separates parameters with the NULL character
-    if(!process->command.isEmpty()) {
+    if(!process->command().isEmpty()) {
         //extract non-truncated name from cmdline
-        int zeroIndex = process->command.indexOf(QChar('\0'));
-        int processNameStart = process->command.lastIndexOf(QChar('/'), zeroIndex);
+        int zeroIndex = process->command().indexOf(QChar('\0'));
+        int processNameStart = process->command().lastIndexOf(QChar('/'), zeroIndex);
         if(processNameStart == -1)
             processNameStart = 0;
         else
             processNameStart++;
-        QString nameFromCmdLine = process->command.mid(processNameStart, zeroIndex - processNameStart);
-        if(nameFromCmdLine.startsWith(process->name))
+        QString nameFromCmdLine = process->command().mid(processNameStart, zeroIndex - processNameStart);
+        if(nameFromCmdLine.startsWith(process->name()))
             process->setName(nameFromCmdLine);
 
-        process->command.replace('\0', ' ');
+        process->command().replace('\0', ' ');
     }
 
     mFile.close();
@@ -407,25 +423,25 @@ bool ProcessesLocal::Private::getNiceness(long pid, Process *process) {
   int sched = sched_getscheduler(pid);
   switch(sched) {
       case (SCHED_OTHER):
-	    process->scheduler = KSysGuard::Process::Other;
+	    process->setScheduler(KSysGuard::Process::Other);
             break;
       case (SCHED_RR):
-	    process->scheduler = KSysGuard::Process::RoundRobin;
+	    process->setScheduler(KSysGuard::Process::RoundRobin);
             break;
       case (SCHED_FIFO):
-	    process->scheduler = KSysGuard::Process::Fifo;
+	    process->setScheduler(KSysGuard::Process::Fifo);
             break;
 #ifdef SCHED_IDLE
       case (SCHED_IDLE):
-	    process->scheduler = KSysGuard::Process::SchedulerIdle;
+	    process->setScheduler(KSysGuard::Process::SchedulerIdle);
 #endif
 #ifdef SCHED_BATCH
       case (SCHED_BATCH):
-	    process->scheduler = KSysGuard::Process::Batch;
+	    process->setScheduler(KSysGuard::Process::Batch);
             break;
 #endif
       default:
-	    process->scheduler = KSysGuard::Process::Other;
+	    process->setScheduler(KSysGuard::Process::Other);
     }
   if(sched == SCHED_FIFO || sched == SCHED_RR) {
     struct sched_param param;
@@ -438,12 +454,12 @@ bool ProcessesLocal::Private::getNiceness(long pid, Process *process) {
 #ifdef HAVE_IONICE
   int ioprio = ioprio_get(IOPRIO_WHO_PROCESS, pid);  /* Returns from 0 to 7 for the iopriority, and -1 if there's an error */
   if(ioprio == -1) {
-	  process->ioniceLevel = -1;
-	  process->ioPriorityClass = KSysGuard::Process::None;
+	  process->setIoniceLevel(-1);
+	  process->setIoPriorityClass(KSysGuard::Process::None);
 	  return false; /* Error. Just give up. */
   }
-  process->ioniceLevel = ioprio & 0xff;  /* Bottom few bits are the priority */
-  process->ioPriorityClass = (KSysGuard::Process::IoPriorityClass)(ioprio >> IOPRIO_CLASS_SHIFT); /* Top few bits are the class */
+  process->setIoniceLevel(ioprio & 0xff);  /* Bottom few bits are the priority */
+  process->setIoPriorityClass((KSysGuard::Process::IoPriorityClass)(ioprio >> IOPRIO_CLASS_SHIFT)); /* Top few bits are the class */
   return true;
 #else
   return false;  /* Do nothing, if we do not support this architecture */
